@@ -1,9 +1,11 @@
 # -*- coding: utf8 -*-
+import os
 from fabric.api import local, run, cd
 from fabric import colors
 from fabric.context_managers import settings
 from fabric.contrib.console import confirm
 from fabric.contrib import django
+from fabric.contrib.files import exists
 from fabric.utils import abort
 
 
@@ -12,10 +14,12 @@ class App(object):
     project_package = None
     test_settings = None
 
-    def __init__(self, project_paths, project_package, test_settings=None):
+    def __init__(self, project_paths, project_package, test_settings=None,
+                 restart_command=None):
         self.project_paths = project_paths
         self.project_package = project_package
-        self.test_settings = None
+        self.test_settings = test_settings
+        self.restart_command = restart_command
         django.project(project_package)
 
     def local_management_command(self, command, *args, **kwargs):
@@ -44,8 +48,17 @@ class App(object):
         else:
             print(colors.green("All tests ok"))
 
+    def check_virtualenv(self, path):
+        venv_path = os.path.join(path, "venv")
+        if not exists(venv_path):
+            if confirm("virtualenv not found. Do you want to create one"):
+                print(colors.yellow("Creating virtualenv"))
+                with cd(path):
+                    run("virtualenv venv")
+
     def run_server_updates(self, instance):
         code_dir = self.project_paths[instance]
+        self.check_virtualenv(code_dir)
         with cd(code_dir):
             run("git fetch")
             run("git reset --hard origin/master")
@@ -62,10 +75,17 @@ class App(object):
             if 'djangobower' in settings.INSTALLED_APPS:
                 self.run_management_command(instance, "bower_install")
 
-            self.run_management_command(instance, "collectstatic --noinput")
+            if 'django.contrib.staticfiles' in settings.INSTALLED_APPS:
+                self.run_management_command(instance,
+                                            "collectstatic --noinput")
 
     def restart_app(self, instance):
-        raise NotImplementedError
+        if self.restart_command is None:
+            # If restart command is not used this method should have been
+            # overrided
+            raise NotImplementedError
+        else:
+            run(self.restart_command)
 
     def deploy(self, instance):
         self.run_server_updates(instance)
